# frozen_string_literal: true
require_dependency 'c/admin_controller'

module C
  class Admin::DocumentsController < AdminController
    load_and_authorize_resource class: C::Document

    def index; end

    def create
      if @document.save
        redirect_to documents_path, notice: 'Document created'
      else
        render :new
      end
    end

    def update
      if @document.update(document_params)
        redirect_to documents_path, notice: 'Document updated'
      else
        render :edit
      end
    end

    def destroy
      @document.delete
      redirect_to documents_path, notice: 'Document deleted'
    end

    def bulk_upload
      count = 0

      params[:documents][:attachments].each do |attachment|
        document = C::Document.new(name: attachment[:attachment].original_filename, document: attachment[:attachment])
        count += 1 if document.save
      end

      redirect_to documents_path, notice: "#{count} document(s) uploaded"
    end

    # TODO: Add a destroy action

    private

    def document_params
      params.require(:document).permit(:document, :name)
    end
  end
end
