# frozen_string_literal: true
module C
  class Page < ApplicationRecord
    include SitePage
    include Imageable
    include Authorable
    include Orderable
    include Previewable
    include Documentable

    acts_as_tree order: 'weight'

    validates :name, presence: true

    has_many :menu_items

    has_many :product_points, dependent: :destroy, class_name: 'ProductPoint'

    accepts_nested_attributes_for :product_points, allow_destroy: true

    before_save do
      self.layout = 'show' if layout.blank?
    end

    def build_product_points
      case product_points.count
      when 3
        return
      when 2
        1.times { product_points.build }
      when 1
        2.times { product_points.build }
      when 0
        3.times { product_points.build }
      else
        return
      end
    end

    INDEX_TABLE = {
      "Name": { link: { name: { call: 'name' }, options: '[:edit, object]' }, sort: 'name' },
      "Author": { call: 'author', sort: 'author' },
      "Published": { call: 'published', sort: 'published' },
      "Created": { call: 'created_at', sort: 'published' },
      "Edit": { link: { name: { text: 'edit' }, options: '[:edit, object]' } }
    }.freeze
  end
end
