# frozen_string_literal: true
module C
  module SitePage
    extend ActiveSupport::Concern

    included do
      scope :published, -> { includes(:page_info).where("c_page_infos.published": true) }

      has_one :page_info, as: :page, dependent: :destroy
      accepts_nested_attributes_for :page_info

      has_one :menu_item, autosave: true
      accepts_nested_attributes_for :menu_item

      delegate :title=, to: :page_info
      delegate :meta_description=, to: :page_info
      delegate :published=, to: :page_info
      delegate :protected=, to: :page_info
      delegate :home_page=, to: :page_info

      delegate :protected, to: :page_info
      delegate :published, to: :page_info
      delegate :home_page, to: :page_info
      delegate :home_page?, to: :page_info
      delegate :title, to: :page_info
      delegate :meta_description, to: :page_info
      delegate :author, to: :page_info

      validates :url_alias, presence: true

      before_validation do
        if url_alias.blank?

          ident = if new_record?
                    self.class.count + 1
                  else
                    id
                  end

          url_pattern = if name.blank?
                          ident
                        else
                          name.parameterize
                        end

          if self.class.find_by(url_alias: url_pattern)
            url_pattern = "#{url_pattern}-#{ident}"
          end
          self.url_alias = url_pattern
        end
      end

      before_create do
        create_page_info unless page_info
      end

      def to_param
        url_alias
      end

      def page_info
        super || build_page_info(page: self)
      end

      def assign_author(user)
        page_info.author_id = user.id
        page_info.save
      end
    end

    class_methods do
      def get_from_url(url=nil)
        # TODO: url alias can be nil w/o being homepage
        # cond = url ? {url_alias: url} : {home_page: true}
        if url
          all.find_by(url_alias: url)
        else
          all.includes(:page_info).find_by(c_page_infos: { home_page: true })
        end
      end

      def root_page
        PageInfo.find_by(page_type: page_type, root: true).page
      end

      PAGE_INFO_ATTRIBUTES = [page_info_attributes: [:id, :title, :meta_description]].freeze
    end
  end
end
