
# frozen_string_literal: true
C::Engine.routes.draw do

  post '/tinymce_assets', to: 'admin/images#create'
  
  scope module: :admin, path: C.admin_mount do
    root 'pages#dashboard'

    devise_for :users, class_name: 'C::User', module: 'c/admin/devise'

    resources :users, except: [:show] do
      get :confirm_destroy, on: :member
      collection do
        resources :roles, except: [:show] do
          member do
            get :confirm_destroy
          end
        end
      end
    end

    resources :pages, except: [:show] do
      collection do
        post :sort
        patch :update_order
      end
      member do
        get :confirm_destroy

        post :dropzone_image
        post :reload_images
        post :destroy_image
        post :set_preview_image
      end
    end

    resources :projects, except: [:show] do
      collection do
        post :sort
        patch :update_order
      end
      member do
        get :confirm_destroy
      end
    end
    resources :testimonials, except: [:show] do
      collection do
        post :sort
        patch :update_order
      end
      member do
        get :confirm_destroy
      end
    end

    resources :blogs, except: [:show] do
      collection do
        post :sort
      end
      member do
        get :confirm_destroy
      end
    end

    resources :locations, except: [:show] do
      member do
        get :confirm_destroy
      end
      collection do
        post :sort
      end
    end

    resources :team_members, except: [:show] do
      collection do
        post :sort
      end
      member do
        get :confirm_destroy
      end
    end

    resources :documents, only: [:index, :new, :create, :edit, :update, :destroy] do
      collection do
        post :bulk_upload
      end
    end

    resources :menu_items, except: [:show] do
      collection do
        patch :update_order
      end
      member do
        get :confirm_destroy
      end
    end

    resources :redirects, except: :show do
      post :bulk_actions, on: :collection
      member do
        get :confirm_destroy
      end
    end

    resources :enquiries, only: [:show, :index, :destroy] do
      get :confirm_destroy, on: :member
    end

    resources :slideshows, only: [:new, :create, :index, :edit, :update] do
      resources :slides, only: [:new, :edit, :create, :update, :destroy] do
        collection do
          post :sort
        end
        member do
          get :confirm_destroy
        end
      end
      member do
        get :confirm_destroy
      end
    end

  end # END OF ADMIN SCOPE

  %w(404 422 500 401).each do |code|
    get code, to: 'errors#show', code: code
  end

  ## FRONT END ROUTES
  # These define the patterns for all routes on the main site
  # You can create individual routes in the main applications when necessary
  namespace :front_end, path: '/' do
    match '/sitemap', to: 'pages#sitemap', via: 'get'

    get '/contact-us', to: 'enquiries#new'
    resources :enquiries, path: 'contact-us', only: [:new, :create] do
      collection do
        get :thanks
      end
    end
    resources :blogs, only: [:index, :show]
    resources :projects, only: [:show]
    resources :pages, only: [:show], path: '/' do
      collection do
        get :search
      end
    end

    root 'pages#show'
  end
end
