# frozen_string_literal: true
module C
  class Engine < ::Rails::Engine
    isolate_namespace C

    config.generators do |g|
      g.test_framework :rspec, fixture: false
      g.fixture_replacement :factory_girl, dir: 'spec/factories'
      g.assets false
      g.helper false
    end

    initializer :append_migrations do |app|
      config.paths['db/migrate'].expanded.each do |expanded_path|
        app.config.paths['db/migrate'] << expanded_path
      end
    end

    initializer 'my_engine.action_controller' do
    end

    # TODO: this puts an error class on fields - is this the best place for it?
    ActionView::Base.field_error_proc = proc do |html_tag, _instance|
      class_attr_index = html_tag.index 'class="'
      if class_attr_index
        html_tag.insert class_attr_index + 7, 'error'
      else
        html_tag.insert html_tag.index('>'), ' class="error"'
      end
    end

    # Date
    Date::DATE_FORMATS[:default] = '%d/%m/%Y'

    # Time
    Time::DATE_FORMATS[:default] = '%H:%M - %d/%m/%Y'
  end
end
