# frozen_string_literal: true
namespace :c do
  task install: [:environment] do
    C::User.create!(name: 'Admin', email: 'web@example.org', password: 'password', cd2admin: true)
    Rake::Task['c:create_permission_subjects'].invoke
    Rake::Task['c:create_admin_role'].invoke
  end

  task create_permission_subjects: :environment do
    C::PermissionSubject.create(name: 'User', subject_type: 'C::User')
    C::PermissionSubject.create(name: 'Category', subject_type: 'C::Category')
    C::PermissionSubject.create(name: 'Roles', subject_type: 'C::Role')
    C::PermissionSubject.create(name: 'Countries', subject_type: 'C::Countries')
    C::PermissionSubject.create(name: 'Settings', subject_type: 'C::Setting')
  end

  task create_admin_role: [:environment, :create_permission_subjects] do
    role = C::Role.create(name: 'Admin', body: 'Main administrator of the store')
    role.build_or_find_permissions
    role.permissions.each do |permission|
      permission.read = true
      permission.new = true
      permission.edit = true
      permission.remove = true
    end
    role.save!
  end
end
